import type { ApolloClient, NormalizedCacheObject } from '@apollo/client'
import { useMemo } from 'react'

import { initializeApolloSSRClient } from '@holi/api/graphql/client'

export const APOLLO_STATE_PROP_NAME = '__APOLLO_STATE__'

export interface ApolloStateProps {
  [APOLLO_STATE_PROP_NAME]?: Record<string, unknown>
}

export const addApolloSSRState = (client: ApolloClient<NormalizedCacheObject> | undefined, props: object) => {
  if (!client) {
    return props
  }

  return {
    ...props,
    // JSON transform as workaround for issue "`undefined` cannot be serialized as JSON. Please use `null` or omit this value all together."
    // see open NextJS issue: https://github.com/vercel/next.js/discussions/11209
    [APOLLO_STATE_PROP_NAME]: JSON.parse(JSON.stringify(client.cache.extract())),
  }
}

export const createApolloSSRClient = (props: ApolloStateProps) => {
  const state = props[APOLLO_STATE_PROP_NAME]
  return initializeApolloSSRClient(state)
}

export const useApolloSSRClient = (props: ApolloStateProps) => {
  const store = useMemo(() => createApolloSSRClient(props), [props])

  return store
}
